# Vibesドキュメント規約

構造化されたyamlによる規約ドキュメントを採用し､プロジェクトの暗黙知を形式知化する事が目的

## ディレクトリ構成

**apis/**: 外部サービス連携（API 仕様書、連携プロトコル）原則変更不可
**logics/**: 
そのシステムで何が出来るか?を把握する
業務ワークフローでディレクトリ整理し､RedmineのEpic-Feature構造と対応させる｡
**rules/**: 
システム品質と一貫性を担保する
設定より規約である｡must_not, should 等でcoderの判断を制御する
**specs/**: 
プロジェクト固有の特殊な技術的要件や仕組みを記載する｡
**tasks/**: 
頻度の少ないが重要なタスクの手順書（リリース手順、障害対応手順）､発生時の影響が大きいタスクを対象とする
**temps/**: 
一時ドキュメント（進行中タスク、検討事項、実装メモ）

## 規約

### 基本原則

- **簡潔性**: 専門用語活用、情報集約、繰り返し回避による圧縮言語での記載｡余計な装飾は避ける
- **一貫性**: 用語・表現の統一、ドキュメント間の整合性維持
- **対応性**: ドキュメントと対応するファイルを`.claude-nagger/file_conventions.yaml`に定義し､ドキュメントの自動注入を行う

## 責務分離

- **バージョン管理は Git の責務**、ドキュメント内容とは別の関心事
- ドキュメントは「何を」「なぜ」「どのように」に集中
- バージョン情報とドキュメント内容を分離し、各々の責務を明確化